% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/definefuns.R
\name{pdotaprox}
\alias{pdotaprox}
\title{Calculating Pdot-approximation coefficients}
\usage{
pdotaprox(stock, sdot, dsdotds, dsdotdss, dwds, dwdss, aproxspace)
}
\arguments{
\item{stock}{An array of stock, \eqn{s}}

\item{sdot}{An array of ds/dt, \eqn{\dot{s}=\frac{ds}{dt}}}

\item{dsdotds}{An array of d(sdot)/ds, \eqn{\frac{d \dot{s}}{d s}}}

\item{dsdotdss}{An array of d/ds(d(sdot)/ds), \eqn{ \frac{d}{ds} \left( \frac{d \dot{s}}{ds} \right)}}

\item{dwds}{An array of dw/ds, \eqn{\frac{dW}{ds}}}

\item{dwdss}{An array of d/ds(dw/ds), \eqn{\frac{d}{ds} \left( \frac{dW}{ds} \right)}}

\item{aproxspace}{An approximation space defined by \code{aproxdef} function}
}
\value{
A list of approximation results: deg, lb, ub, delta, and coefficients
}
\description{
The function provides the Pdot-approximation coefficients of the defined Chebyshev polynomials in \code{aproxdef}.
             For now, only unidimensional case is developed.
}
\details{
The Pdot-approximation is finding the shadow price of a stock, \eqn{p} from the relation:\cr
\cr
\eqn{p(s) = \frac{W_{s}(s) + \dot{p}(s)}{\delta - \dot{s}_{s}}}, \cr
\cr
where \eqn{W_{s} = \frac{dW}{ds}}, \eqn{ \dot{p}(s) = \frac{dp}{ds}},
\eqn{\dot{s}_{s} = \frac{d\dot{s}}{ds} }, and \eqn{\delta} is the given discount rate.\cr
\cr
In order to operationhalize this approach, we take the time derivative of this expression:\cr
\cr
\eqn{ \dot{p} = \frac{ \left( \left(W_{ss}\dot{s} + \ddot{p} \right) \left( \delta - \dot{s}_{s} \right) +
   \left( W_{s} + \dot{p} \right) \left(\dot{s}_{ss} \dot{s} \right)  \right)  }
   { \left( \delta - \dot{s}_{s} \right)^{2} } } \cr
\cr
Consider approximation \eqn{ \dot{p}(s) = \mathbf{\mu}(s)\mathbf{\beta}}, \eqn{\mathbf{\mu}(s)}
is Chebyshev polynomials and \eqn{\mathbf{\beta}} is their coeffcients.
Then, \eqn{ \ddot{p} = \frac{ d \dot{p}}{ds} \frac{ds}{dt} = \dot{s} \mathbf{\mu}_{s}(s) \mathbf{\beta}} by the orthogonality of Chebyshev basis.
Adopting the properties above, we can get the unknown coefficient vector \eqn{\beta} from:\cr
\cr
\eqn{ \mathbf{\mu \beta} =  \left( \delta - \dot{s}_{s} \right)^{-2}
   \left[ \left(W_{ss}\dot{s} + \dot{s} \mathbf{\mu}_{s} \mathbf{\beta} \right)\left( \delta - \dot{s}_{s} \right) +
   \left( W_{s} + \mathbf{\mu \beta} \right) \left(\dot{s}_{ss} \dot{s} \right)  \right] }, and \cr
\cr
\eqn{\mathbf{\beta} = \left[ \left( \delta - \dot{s}_{s} \right)^{2} \mathbf{\mu} - \dot{s}\left( \delta - \dot{s}_{s} \right) \mathbf{\mu}_{s}
    - \dot{s}_{ss} \dot{s} \mathbf{\mu}   \right]^{-1}
    \left( W_{ss} \dot{s} \left( \delta - \dot{s}_{s} \right) + W_{s} \dot{s}_{ss} \dot{s} \right) }.  \cr
\cr
If we suppose \eqn{ A = \left[ \left( \delta - \dot{s}_{s} \right)^{2} \mathbf{\mu} - \dot{s}\left( \delta - \dot{s}_{s} \right) \mathbf{\mu}_{s}
    - \dot{s}_{ss} \dot{s} \mathbf{\mu}   \right] } and \eqn{ B = \left( W_{ss} \dot{s} \left( \delta - \dot{s}_{s} \right) + W_{s} \dot{s}_{ss} \dot{s} \right) },
then over-determined case can be calculated:\cr
\cr
\eqn{ \mathbf{\beta} = \left( A^{T}A \right)^{-1} A^{T}B }.\cr
\cr
For more detils see Fenichel and Abbott (2014) and Fenichel et al. (2016).
}
\examples{
## 1-D Reef-fish example: see Fenichel and Abbott (2014)
data("reefdata")
st <- reefaproxdata[,1]
sdot <- reefaproxdata[,2]
dsdotds <- reefaproxdata[,3]
dsdotdss <- reefaproxdata[,4]
dwds <- reefaproxdata[,6]
dwdss <- reefaproxdata[,7]
aproxdeg <- 50
lower <- 5*10^6
upper <- 359016000
delta <- 0.02
reefspace <- aproxdef(aproxdeg,lower,upper,delta)
pdotaproxc <- pdotaprox(st,sdot,dsdotds, dsdotdss,dwds, dwdss,reefspace)
}
\references{
Fenichel, Eli P. and Joshua K. Abbott. (2014) "\href{http://www.journals.uchicago.edu/doi/abs/10.1086/676034}{Natural Capital: From Metaphor to Measurement}."
             \emph{Journal of the Association of Environmental Economists}. 1(1/2):1-27.
}
\seealso{
\code{\link{aproxdef}, \link{pdotsim}}
}

