% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/definefuns.R
\name{pdotsim}
\alias{pdotsim}
\title{Simulation of Pdot-approximation}
\usage{
pdotsim(stock, sdot, dsdotds, wval, dwds, pdotcoeff)
}
\arguments{
\item{stock}{An array of stock}

\item{sdot}{An array of ds/dt, \eqn{\dot{s}=\frac{ds}{dt}}}

\item{dsdotds}{An array of d(sdot)/ds, \eqn{\frac{d \dot{s}}{d s}}}

\item{wval}{An array of \eqn{W}-value}

\item{dwds}{An array of dw/ds, \eqn{\frac{dW}{ds}}}

\item{pdotcoeff}{An approximation result from \code{pdotaprox} function}
}
\value{
A list of approximation resuts: shadow (accounting) prices, inclusive wealth, and Value function
}
\description{
The function provides the Pdot-approximation simulation.
}
\details{
Let \eqn{\hat{\beta}} be the approximation coefficent from the results of \code{pdotaprox} function.
The estimated shadow price (accounting) price of stock over the given approximation intervals of
\eqn{s \in [a,b]}, \eqn{\hat{p}} can be calculated as:\cr
\cr
\eqn{\hat{p} = \frac{ W_{s} + \mathbf{\mu \beta} }{ \delta - \dot{s}_{s} } }.\cr
\cr
The estimated inclusive wealth is:\cr
\cr
\eqn{IW = \hat{p}s }. \cr
\cr
The estimated value function is:\cr
\cr
\eqn{ \hat{V} = \frac{1}{\delta} \left( W + \hat{p} \dot{s} \right)  }.\cr
\cr
For more detils see Fenichel and Abbott (2014) and Fenichel et al. (2016).
}
\examples{
## 1-D Reef-fish example: see Fenichel and Abbott (2014)
data("reefdata")
st <- reefaproxdata[,1]
sdot <- reefaproxdata[,2]
dsdotds <- reefaproxdata[,3]
dsdotdss <- reefaproxdata[,4]
dwds <- reefaproxdata[,6]
dwdss <- reefaproxdata[,7]
aproxdeg <- 50
lower <- 5*10^6
upper <- 359016000
delta <- 0.02
reefspace <- aproxdef(aproxdeg,lower,upper,delta)
pdotaproxc <- pdotaprox(st,sdot,dsdotds, dsdotdss,dwds, dwdss,reefspace)

# approximation domain
st1 <- reefsimdata[,1]
sdot1 <- reefsimdata[,2]
dsdotds1 <- reefsimdata[,3]
wval1 <- reefsimdata[,5]
dwds1 <- reefsimdata[,6]
reefsim <- pdotsim(st1,sdot1,dsdotds1,wval1,dwds1,pdotaproxc)

# Accounting Price
plot(st1,reefsim[["shadowp"]],type='l', lwd=2, col="blue",
     ylim = c(0,30),
     xlab="Stock size, s",
     ylab="Accounting price")

# Inclusive Wealth
plot(st1,reefsim[["iw"]],type='l', lwd=2, col="blue",
     xlab="Stock size, s",
     ylab="Inclusive Wealth")
}
\seealso{
\code{\link{pdotaprox}}
}

