% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/definefuns.R
\name{vsim}
\alias{vsim}
\title{Simulation of V-approximation}
\usage{
vsim(adata, vcoeff)
}
\arguments{
\item{adata}{A data.frame or matrix of [stock,sdot,benefit]=[\eqn{\mathbf{S}},\eqn{\mathbf{\dot{S}}},\eqn{W}]}

\item{vcoeff}{An approximation result from \code{varpox} function}
}
\value{
A list of simulation resuts: shadow (accounting) prices, inclusive wealth, and Value function
}
\description{
The function provides the V-approximation simulation by adopting the results of \code{vaprox}. Available for multiple stock problems.
}
\details{
Let \eqn{\hat{\beta}} be the approximation coefficent from the results of \code{vaprox} function.
The estimated shadow (accounting) price of \eqn{i}-th stock over the given approximation intervals of \eqn{s_{i} \in [a_{i},b_{i}]},
\eqn{\hat{p}_{i}} can be calcuated as:\cr
\cr
\eqn{\hat{p}_{i} = \mathbf{\mu}(\mathbf{S})\mathbf{\hat{\beta}}} where \eqn{\mathbf{\mu}(\mathbf{S})} Chebyshev polynomial basis.\cr
\cr
The Inclusive wealth of \eqn{i}-th stock is:\cr
\cr
\eqn{IW = \displaystyle \sum_{i}^{d} \hat{p}_{i} s_{i} }, and \cr
\cr
the value function is:\cr
\cr
\eqn{\hat{V} = \delta \mathbf{\mu}(\mathbf{S})\mathbf{\hat{\beta}}}.\cr
\cr
For more detils see Fenichel and Abbott (2014) and Fenichel et al. (2016).
}
\examples{
## 1-D Reef-fish example: see Fenichel and Abbott (2014)
data("reefdata")
# Note vcol function requries a data.frame or matrix!
aproxdata <- matrix(cbind(reefaproxdata[,1],reefaproxdata[,2],reefaproxdata[,5]),ncol=3)
aproxdeg <- 20
lower <- 5*10^6
upper <- 359016000
delta <- 0.02
reefspace <- aproxdef(aproxdeg,lower,upper,delta)
vaproxc <- vaprox(aproxdata,reefspace)
stapprox <- matrix(reefsimdata[,1])
reefsim <- vsim(stapprox,vaproxc)

# plot shadow (accounting) price: Figure 4 in Fenichel and Abbott (2014)
plot(stapprox,reefsim[["shadowp"]],type='l', lwd=2, col="blue",
     ylim = c(0,15),
     xlab="Stock size, s",
     ylab="Accounting price")

## 2-D Prey-Predator example
data("lvdata")
aproxdeg <- c(20,20)
lower <- c(0.1,0.1)
upper <- c(1.5,1.5)
delta <- 0.03
lvspace <- aproxdef(aproxdeg,lower,upper,delta)
lvaproxc <- vaprox(lvaproxdata,lvspace)
lvsim <- vsim(lvsimdata.time[,2:3],lvaproxc)

# plot Biomass
plot(lvsimdata.time[,1], lvsimdata.time[,2], type='l', lwd=2, col="blue",
     xlab="Time",
     ylab="Biomass")
lines(lvsimdata.time[,1], lvsimdata.time[,3], lwd=2, col="red")
legend("topright", c("Prey", "Predator"), col=c("blue", "red"),
       lty=c(1,1), lwd=c(2,2), bty="n")

# plot shadow (accounting) prices
plot(lvsimdata.time[,1],lvsim[["shadowp"]][,1],type='l', lwd=2, col="blue",
     ylim = c(-5,7),
     xlab="Time",
     ylab="Accounting price")
lines(lvsimdata.time[,1],lvsim[["shadowp"]][,2], lwd=2, col="red")
legend("topright", c("Prey", "Predator"), col=c("blue", "red"),
       lty=c(1,1), lwd=c(2,2), bty="n")

# plot inclusive weath and value function
plot(lvsimdata.time[,1],lvsim[["iw"]],type='l', lwd=2, col="blue",
     ylim = c(-0.5,1.2),
     xlab="Time",
     ylab="Inclusive Wealth / Value Function ($)")
lines(lvsimdata.time[,1],lvsim[["vfun"]], lwd=2, col="red")
legend("topright", c("Inclusive Wealth", "Value Function"),
       col=c("blue", "red"), lty=c(1,1), lwd=c(2,2), bty="n")
}
\references{
Fenichel, Eli P. and Joshua K. Abbott. (2014) "\href{http://www.journals.uchicago.edu/doi/abs/10.1086/676034}{Natural Capital: From Metaphor to Measurement}."
             \emph{Journal of the Association of Environmental Economists}. 1(1/2):1-27.
}
\seealso{
\code{\link{aproxdef}, \link{vsim}}
}

